from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Dvl(_message.Message):
    __slots__ = ("header", "ros2_header", "velocity_mode", "dvl_type", "velocity", "velocity_covar", "altitude", "course_gnd", "speed_gnd", "num_good_beams", "sound_speed", "beam_ranges_valid", "beam_velocities_valid", "beam_unit_vec", "range", "range_covar", "beam_quality", "beam_velocity", "beam_velocity_covar")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_MODE_FIELD_NUMBER: _ClassVar[int]
    DVL_TYPE_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_COVAR_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    COURSE_GND_FIELD_NUMBER: _ClassVar[int]
    SPEED_GND_FIELD_NUMBER: _ClassVar[int]
    NUM_GOOD_BEAMS_FIELD_NUMBER: _ClassVar[int]
    SOUND_SPEED_FIELD_NUMBER: _ClassVar[int]
    BEAM_RANGES_VALID_FIELD_NUMBER: _ClassVar[int]
    BEAM_VELOCITIES_VALID_FIELD_NUMBER: _ClassVar[int]
    BEAM_UNIT_VEC_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    RANGE_COVAR_FIELD_NUMBER: _ClassVar[int]
    BEAM_QUALITY_FIELD_NUMBER: _ClassVar[int]
    BEAM_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    BEAM_VELOCITY_COVAR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    velocity_mode: int
    dvl_type: int
    velocity: _vector3_pb2.Vector3
    velocity_covar: _containers.RepeatedScalarFieldContainer[float]
    altitude: float
    course_gnd: float
    speed_gnd: float
    num_good_beams: int
    sound_speed: float
    beam_ranges_valid: bool
    beam_velocities_valid: bool
    beam_unit_vec: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    range: _containers.RepeatedScalarFieldContainer[float]
    range_covar: _containers.RepeatedScalarFieldContainer[float]
    beam_quality: _containers.RepeatedScalarFieldContainer[float]
    beam_velocity: _containers.RepeatedScalarFieldContainer[float]
    beam_velocity_covar: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., velocity_mode: _Optional[int] = ..., dvl_type: _Optional[int] = ..., velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., velocity_covar: _Optional[_Iterable[float]] = ..., altitude: _Optional[float] = ..., course_gnd: _Optional[float] = ..., speed_gnd: _Optional[float] = ..., num_good_beams: _Optional[int] = ..., sound_speed: _Optional[float] = ..., beam_ranges_valid: bool = ..., beam_velocities_valid: bool = ..., beam_unit_vec: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., range: _Optional[_Iterable[float]] = ..., range_covar: _Optional[_Iterable[float]] = ..., beam_quality: _Optional[_Iterable[float]] = ..., beam_velocity: _Optional[_Iterable[float]] = ..., beam_velocity_covar: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.rolling.rcl_interfaces.msg import parameter_pb2 as _parameter_pb2
from make87_messages_ros2.rolling.rcl_interfaces.msg import set_parameters_result_pb2 as _set_parameters_result_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetParametersRequest(_message.Message):
    __slots__ = ("parameters",)
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    parameters: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    def __init__(self, parameters: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ...) -> None: ...

class SetParametersResponse(_message.Message):
    __slots__ = ("results",)
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[_set_parameters_result_pb2.SetParametersResult]
    def __init__(self, results: _Optional[_Iterable[_Union[_set_parameters_result_pb2.SetParametersResult, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/rxm_svsi.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import rxm_svsisv_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_rxm__svsisv__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/rxm_svsi.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a:make87_messages_ros2/jazzy/ublox_msgs/msg/rxm_svsisv.proto\"\x89\x01\n\x07RxmSVSI\x12\r\n\x05i_tow\x18\x01 \x01(\x05\x12\x0c\n\x04week\x18\x02 \x01(\x05\x12\x0f\n\x07num_vis\x18\x03 \x01(\r\x12\x0e\n\x06num_sv\x18\x04 \x01(\r\x12@\n\x02sv\x18\x05 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.ublox_msgs.msg.RxmSVSISVb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.rxm_svsi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RXMSVSI']._serialized_start=164
  _globals['_RXMSVSI']._serialized_end=301
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RobotStateRTMsg(_message.Message):
    __slots__ = ("header", "time", "q_target", "qd_target", "qdd_target", "i_target", "m_target", "q_actual", "qd_actual", "i_actual", "tool_acc_values", "tcp_force", "tool_vector", "tcp_speed", "digital_input_bits", "motor_temperatures", "controller_timer", "test_value", "robot_mode", "joint_modes")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    Q_TARGET_FIELD_NUMBER: _ClassVar[int]
    QD_TARGET_FIELD_NUMBER: _ClassVar[int]
    QDD_TARGET_FIELD_NUMBER: _ClassVar[int]
    I_TARGET_FIELD_NUMBER: _ClassVar[int]
    M_TARGET_FIELD_NUMBER: _ClassVar[int]
    Q_ACTUAL_FIELD_NUMBER: _ClassVar[int]
    QD_ACTUAL_FIELD_NUMBER: _ClassVar[int]
    I_ACTUAL_FIELD_NUMBER: _ClassVar[int]
    TOOL_ACC_VALUES_FIELD_NUMBER: _ClassVar[int]
    TCP_FORCE_FIELD_NUMBER: _ClassVar[int]
    TOOL_VECTOR_FIELD_NUMBER: _ClassVar[int]
    TCP_SPEED_FIELD_NUMBER: _ClassVar[int]
    DIGITAL_INPUT_BITS_FIELD_NUMBER: _ClassVar[int]
    MOTOR_TEMPERATURES_FIELD_NUMBER: _ClassVar[int]
    CONTROLLER_TIMER_FIELD_NUMBER: _ClassVar[int]
    TEST_VALUE_FIELD_NUMBER: _ClassVar[int]
    ROBOT_MODE_FIELD_NUMBER: _ClassVar[int]
    JOINT_MODES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time: float
    q_target: _containers.RepeatedScalarFieldContainer[float]
    qd_target: _containers.RepeatedScalarFieldContainer[float]
    qdd_target: _containers.RepeatedScalarFieldContainer[float]
    i_target: _containers.RepeatedScalarFieldContainer[float]
    m_target: _containers.RepeatedScalarFieldContainer[float]
    q_actual: _containers.RepeatedScalarFieldContainer[float]
    qd_actual: _containers.RepeatedScalarFieldContainer[float]
    i_actual: _containers.RepeatedScalarFieldContainer[float]
    tool_acc_values: _containers.RepeatedScalarFieldContainer[float]
    tcp_force: _containers.RepeatedScalarFieldContainer[float]
    tool_vector: _containers.RepeatedScalarFieldContainer[float]
    tcp_speed: _containers.RepeatedScalarFieldContainer[float]
    digital_input_bits: float
    motor_temperatures: _containers.RepeatedScalarFieldContainer[float]
    controller_timer: float
    test_value: float
    robot_mode: float
    joint_modes: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time: _Optional[float] = ..., q_target: _Optional[_Iterable[float]] = ..., qd_target: _Optional[_Iterable[float]] = ..., qdd_target: _Optional[_Iterable[float]] = ..., i_target: _Optional[_Iterable[float]] = ..., m_target: _Optional[_Iterable[float]] = ..., q_actual: _Optional[_Iterable[float]] = ..., qd_actual: _Optional[_Iterable[float]] = ..., i_actual: _Optional[_Iterable[float]] = ..., tool_acc_values: _Optional[_Iterable[float]] = ..., tcp_force: _Optional[_Iterable[float]] = ..., tool_vector: _Optional[_Iterable[float]] = ..., tcp_speed: _Optional[_Iterable[float]] = ..., digital_input_bits: _Optional[float] = ..., motor_temperatures: _Optional[_Iterable[float]] = ..., controller_timer: _Optional[float] = ..., test_value: _Optional[float] = ..., robot_mode: _Optional[float] = ..., joint_modes: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_planning_msgs/msg/trajectory_point.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/autoware_planning_msgs/msg/trajectory_point.proto\x12\x36make87_messages_ros2.humble.autoware_planning_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/builtin_interfaces/msg/duration.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\"\x8c\x03\n\x0fTrajectoryPoint\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12U\n\x0ftime_from_start\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.humble.builtin_interfaces.msg.Duration\x12\x41\n\x04pose\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12!\n\x19longitudinal_velocity_mps\x18\x04 \x01(\x02\x12\x1c\n\x14lateral_velocity_mps\x18\x05 \x01(\x02\x12\x19\n\x11\x61\x63\x63\x65leration_mps2\x18\x06 \x01(\x02\x12\x18\n\x10heading_rate_rps\x18\x07 \x01(\x02\x12\x1d\n\x15\x66ront_wheel_angle_rad\x18\x08 \x01(\x02\x12\x1c\n\x14rear_wheel_angle_rad\x18\t \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_planning_msgs.msg.trajectory_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAJECTORYPOINT']._serialized_start=298
  _globals['_TRAJECTORYPOINT']._serialized_end=694
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EndpointAddRequest(_message.Message):
    __slots__ = ("url", "type")
    URL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    url: str
    type: int
    def __init__(self, url: _Optional[str] = ..., type: _Optional[int] = ...) -> None: ...

class EndpointAddResponse(_message.Message):
    __slots__ = ("successful", "reason", "id")
    SUCCESSFUL_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    successful: bool
    reason: str
    id: int
    def __init__(self, successful: bool = ..., reason: _Optional[str] = ..., id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_babel_fish_test_msgs/msg/test_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg import test_sub_array_pb2 as make87__messages__ros2_dot_rolling_dot_ros__babel__fish__test__msgs_dot_msg_dot_test__sub__array__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/ros_babel_fish_test_msgs/msg/test_array.proto\x12\x39make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1aNmake87_messages_ros2/rolling/ros_babel_fish_test_msgs/msg/test_sub_array.proto\"\xab\x04\n\tTestArray\x12\r\n\x05\x62ools\x18\x01 \x03(\x08\x12\x0e\n\x06uint8s\x18\x02 \x03(\r\x12\x0f\n\x07uint16s\x18\x03 \x03(\r\x12\x0f\n\x07uint32s\x18\x04 \x03(\r\x12\x0f\n\x07uint64s\x18\x05 \x03(\x04\x12\r\n\x05int8s\x18\x06 \x03(\x05\x12\x0e\n\x06int16s\x18\x07 \x03(\x05\x12\x0e\n\x06int32s\x18\x08 \x03(\x05\x12\x0e\n\x06int64s\x18\t \x03(\x03\x12\x10\n\x08\x66loat32s\x18\n \x03(\x02\x12\x10\n\x08\x66loat64s\x18\x0b \x03(\x01\x12H\n\x05times\x18\x0c \x03(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12P\n\tdurations\x18\r \x03(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Duration\x12\x0f\n\x07strings\x18\x0e \x03(\t\x12`\n\x0fsubarrays_fixed\x18\x0f \x03(\x0b\x32G.make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg.TestSubArray\x12Z\n\tsubarrays\x18\x10 \x03(\x0b\x32G.make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg.TestSubArrayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_babel_fish_test_msgs.msg.test_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTARRAY']._serialized_start=350
  _globals['_TESTARRAY']._serialized_end=905
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(_message.Message):
    __slots__ = ("step", "list_node_open", "list_edge_open", "color_open", "list_node_closed", "list_edge_closed", "color_closed")
    STEP_FIELD_NUMBER: _ClassVar[int]
    LIST_NODE_OPEN_FIELD_NUMBER: _ClassVar[int]
    LIST_EDGE_OPEN_FIELD_NUMBER: _ClassVar[int]
    COLOR_OPEN_FIELD_NUMBER: _ClassVar[int]
    LIST_NODE_CLOSED_FIELD_NUMBER: _ClassVar[int]
    LIST_EDGE_CLOSED_FIELD_NUMBER: _ClassVar[int]
    COLOR_CLOSED_FIELD_NUMBER: _ClassVar[int]
    step: int
    list_node_open: _containers.RepeatedScalarFieldContainer[int]
    list_edge_open: _containers.RepeatedScalarFieldContainer[int]
    color_open: _containers.RepeatedCompositeFieldContainer[_color_rgba_pb2.ColorRGBA]
    list_node_closed: _containers.RepeatedScalarFieldContainer[int]
    list_edge_closed: _containers.RepeatedScalarFieldContainer[int]
    color_closed: _containers.RepeatedCompositeFieldContainer[_color_rgba_pb2.ColorRGBA]
    def __init__(self, step: _Optional[int] = ..., list_node_open: _Optional[_Iterable[int]] = ..., list_edge_open: _Optional[_Iterable[int]] = ..., color_open: _Optional[_Iterable[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]]] = ..., list_node_closed: _Optional[_Iterable[int]] = ..., list_edge_closed: _Optional[_Iterable[int]] = ..., color_closed: _Optional[_Iterable[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/msg/odom_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import camera_models_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_camera__models__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import key_point_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_key__point__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import point2f_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_point2f__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import point3f_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_point3f__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/humble/rtabmap_msgs/msg/odom_info.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a=make87_messages_ros2/humble/geometry_msgs/msg/transform.proto\x1a@make87_messages_ros2/humble/rtabmap_msgs/msg/camera_models.proto\x1a<make87_messages_ros2/humble/rtabmap_msgs/msg/key_point.proto\x1a:make87_messages_ros2/humble/rtabmap_msgs/msg/point2f.proto\x1a:make87_messages_ros2/humble/rtabmap_msgs/msg/point3f.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x9f\x0e\n\x08OdomInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04lost\x18\x03 \x01(\x08\x12\x0f\n\x07matches\x18\x04 \x01(\x05\x12\x0f\n\x07inliers\x18\x05 \x01(\x05\x12\x19\n\x11icp_inliers_ratio\x18\x06 \x01(\x02\x12\x14\n\x0cicp_rotation\x18\x07 \x01(\x02\x12\x17\n\x0ficp_translation\x18\x08 \x01(\x02\x12!\n\x19icp_structural_complexity\x18\t \x01(\x02\x12#\n\x1bicp_structural_distribution\x18\n \x01(\x02\x12\x1b\n\x13icp_correspondences\x18\x0b \x01(\x05\x12\x12\n\ncovariance\x18\x0c \x03(\x01\x12\x10\n\x08\x66\x65\x61tures\x18\r \x01(\x05\x12\x16\n\x0elocal_map_size\x18\x0e \x01(\x05\x12\x1b\n\x13local_scan_map_size\x18\x0f \x01(\x05\x12\x18\n\x10local_key_frames\x18\x10 \x01(\x05\x12\x1d\n\x15local_bundle_outliers\x18\x11 \x01(\x05\x12 \n\x18local_bundle_constraints\x18\x12 \x01(\x05\x12\x19\n\x11local_bundle_time\x18\x13 \x01(\x02\x12\x17\n\x0fkey_frame_added\x18\x14 \x01(\x08\x12\x17\n\x0ftime_estimation\x18\x15 \x01(\x02\x12\x1f\n\x17time_particle_filtering\x18\x16 \x01(\x02\x12\r\n\x05stamp\x18\x17 \x01(\x02\x12\x10\n\x08interval\x18\x18 \x01(\x02\x12\x1a\n\x12\x64istance_travelled\x18\x19 \x01(\x02\x12\x14\n\x0cmemory_usage\x18\x1a \x01(\x05\x12\x1a\n\x12gravity_roll_error\x18\x1b \x01(\x02\x12\x1b\n\x13gravity_pitch_error\x18\x1c \x01(\x02\x12\x18\n\x10local_bundle_ids\x18\x1d \x03(\x05\x12W\n\x13local_bundle_models\x18\x1e \x03(\x0b\x32:.make87_messages_ros2.humble.rtabmap_msgs.msg.CameraModels\x12O\n\x12local_bundle_poses\x18\x1f \x03(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12K\n\ttransform\x18  \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12T\n\x12transform_filtered\x18! \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12X\n\x16transform_ground_truth\x18\" \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12G\n\x05guess\x18# \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transform\x12\x0c\n\x04type\x18$ \x01(\x05\x12\x12\n\nwords_keys\x18% \x03(\x05\x12L\n\x0cwords_values\x18& \x03(\x0b\x32\x36.make87_messages_ros2.humble.rtabmap_msgs.msg.KeyPoint\x12\x14\n\x0cword_matches\x18\' \x03(\x05\x12\x14\n\x0cword_inliers\x18( \x03(\x05\x12\x16\n\x0elocal_map_keys\x18) \x03(\x05\x12O\n\x10local_map_values\x18* \x03(\x0b\x32\x35.make87_messages_ros2.humble.rtabmap_msgs.msg.Point3f\x12P\n\x0elocal_scan_map\x18+ \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12J\n\x0bref_corners\x18, \x03(\x0b\x32\x35.make87_messages_ros2.humble.rtabmap_msgs.msg.Point2f\x12J\n\x0bnew_corners\x18- \x03(\x0b\x32\x35.make87_messages_ros2.humble.rtabmap_msgs.msg.Point2f\x12\x16\n\x0e\x63orner_inliers\x18. \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.msg.odom_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ODOMINFO']._serialized_start=634
  _globals['_ODOMINFO']._serialized_end=2457
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marine_acoustic_msgs/msg/sonar_detections.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marine_acoustic_msgs.msg import detection_flag_pb2 as make87__messages__ros2_dot_rolling_dot_marine__acoustic__msgs_dot_msg_dot_detection__flag__pb2
from make87_messages_ros2.rolling.marine_acoustic_msgs.msg import ping_info_pb2 as make87__messages__ros2_dot_rolling_dot_marine__acoustic__msgs_dot_msg_dot_ping__info__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/marine_acoustic_msgs/msg/sonar_detections.proto\x12\x35make87_messages_ros2.rolling.marine_acoustic_msgs.msg\x1aJmake87_messages_ros2/rolling/marine_acoustic_msgs/msg/detection_flag.proto\x1a\x45make87_messages_ros2/rolling/marine_acoustic_msgs/msg/ping_info.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe9\x02\n\x0fSonarDetections\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12R\n\tping_info\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.rolling.marine_acoustic_msgs.msg.PingInfo\x12S\n\x05\x66lags\x18\x03 \x03(\x0b\x32\x44.make87_messages_ros2.rolling.marine_acoustic_msgs.msg.DetectionFlag\x12\x1c\n\x14two_way_travel_times\x18\x04 \x03(\x02\x12\x11\n\ttx_delays\x18\x05 \x03(\x02\x12\x13\n\x0bintensities\x18\x06 \x03(\x02\x12\x11\n\ttx_angles\x18\x07 \x03(\x02\x12\x11\n\trx_angles\x18\x08 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marine_acoustic_msgs.msg.sonar_detections_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SONARDETECTIONS']._serialized_start=339
  _globals['_SONARDETECTIONS']._serialized_end=700
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/tuw_object_msgs/msg/object_with_covariance_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.humble.tuw_object_msgs.msg import object_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_tuw__object__msgs_dot_msg_dot_object__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/humble/tuw_object_msgs/msg/object_with_covariance_array.proto\x12/make87_messages_ros2.humble.tuw_object_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\x1aLmake87_messages_ros2/humble/tuw_object_msgs/msg/object_with_covariance.proto\"\xe8\x01\n\x19ObjectWithCovarianceArray\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12V\n\x07objects\x18\x03 \x03(\x0b\x32\x45.make87_messages_ros2.humble.tuw_object_msgs.msg.ObjectWithCovarianceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.tuw_object_msgs.msg.object_with_covariance_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECTWITHCOVARIANCEARRAY']._serialized_start=304
  _globals['_OBJECTWITHCOVARIANCEARRAY']._serialized_end=536
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.mavros_msgs.msg import param_value_pb2 as _param_value_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParamSetRequest(_message.Message):
    __slots__ = ("header", "param_id", "value")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PARAM_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    param_id: str
    value: _param_value_pb2.ParamValue
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., param_id: _Optional[str] = ..., value: _Optional[_Union[_param_value_pb2.ParamValue, _Mapping]] = ...) -> None: ...

class ParamSetResponse(_message.Message):
    __slots__ = ("header", "success", "value")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    value: _param_value_pb2.ParamValue
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., value: _Optional[_Union[_param_value_pb2.ParamValue, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.sensor_msgs.msg import laser_scan_pb2 as _laser_scan_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExtendedLaserScan(_message.Message):
    __slots__ = ("laser_scan", "reflektor_status", "reflektor_median", "intrusion")
    LASER_SCAN_FIELD_NUMBER: _ClassVar[int]
    REFLEKTOR_STATUS_FIELD_NUMBER: _ClassVar[int]
    REFLEKTOR_MEDIAN_FIELD_NUMBER: _ClassVar[int]
    INTRUSION_FIELD_NUMBER: _ClassVar[int]
    laser_scan: _laser_scan_pb2.LaserScan
    reflektor_status: _containers.RepeatedScalarFieldContainer[bool]
    reflektor_median: _containers.RepeatedScalarFieldContainer[bool]
    intrusion: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, laser_scan: _Optional[_Union[_laser_scan_pb2.LaserScan, _Mapping]] = ..., reflektor_status: _Optional[_Iterable[bool]] = ..., reflektor_median: _Optional[_Iterable[bool]] = ..., intrusion: _Optional[_Iterable[bool]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerSetPitchyaw(_message.Message):
    __slots__ = ("header", "target_system", "target_component", "flags", "gimbal_device_id", "pitch", "yaw", "pitch_rate", "yaw_rate")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TARGET_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TARGET_COMPONENT_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    PITCH_RATE_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    target_system: int
    target_component: int
    flags: int
    gimbal_device_id: int
    pitch: float
    yaw: float
    pitch_rate: float
    yaw_rate: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., target_system: _Optional[int] = ..., target_component: _Optional[int] = ..., flags: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ..., pitch: _Optional[float] = ..., yaw: _Optional[float] = ..., pitch_rate: _Optional[float] = ..., yaw_rate: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrajectoryStates(_message.Message):
    __slots__ = ("header", "trajectory_id", "trajectory_state")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_STATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    trajectory_id: _containers.RepeatedScalarFieldContainer[int]
    trajectory_state: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., trajectory_id: _Optional[_Iterable[int]] = ..., trajectory_state: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OpticalFlow(_message.Message):
    __slots__ = ("header", "flow", "flow_comp_m", "quality", "ground_distance", "flow_rate")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FLOW_FIELD_NUMBER: _ClassVar[int]
    FLOW_COMP_M_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    GROUND_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    FLOW_RATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    flow: _vector3_pb2.Vector3
    flow_comp_m: _vector3_pb2.Vector3
    quality: int
    ground_distance: float
    flow_rate: _vector3_pb2.Vector3
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., flow: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., flow_comp_m: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., quality: _Optional[int] = ..., ground_distance: _Optional[float] = ..., flow_rate: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrStatus4(_message.Message):
    __slots__ = ("header", "can_tx_sw_version_host", "can_tx_path_id_blis_ignore", "can_tx_path_id_blis", "can_tx_angle_misalignment", "can_tx_auto_align_angle")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_SW_VERSION_HOST_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_PATH_ID_BLIS_IGNORE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_PATH_ID_BLIS_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_ANGLE_MISALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_AUTO_ALIGN_ANGLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_tx_sw_version_host: int
    can_tx_path_id_blis_ignore: int
    can_tx_path_id_blis: int
    can_tx_angle_misalignment: float
    can_tx_auto_align_angle: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_tx_sw_version_host: _Optional[int] = ..., can_tx_path_id_blis_ignore: _Optional[int] = ..., can_tx_path_id_blis: _Optional[int] = ..., can_tx_angle_misalignment: _Optional[float] = ..., can_tx_auto_align_angle: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DispatchCommand(_message.Message):
    __slots__ = ("header", "fleet_name", "task_id", "dispatch_id", "timestamp", "type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    DISPATCH_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fleet_name: str
    task_id: str
    dispatch_id: int
    timestamp: _time_pb2.Time
    type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fleet_name: _Optional[str] = ..., task_id: _Optional[str] = ..., dispatch_id: _Optional[int] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., type: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class OutputPaths(_message.Message):
    __slots__ = ("status", "is_safe", "is_valid", "active_monitoring_case")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    IS_SAFE_FIELD_NUMBER: _ClassVar[int]
    IS_VALID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_MONITORING_CASE_FIELD_NUMBER: _ClassVar[int]
    status: _containers.RepeatedScalarFieldContainer[bool]
    is_safe: _containers.RepeatedScalarFieldContainer[bool]
    is_valid: _containers.RepeatedScalarFieldContainer[bool]
    active_monitoring_case: int
    def __init__(self, status: _Optional[_Iterable[bool]] = ..., is_safe: _Optional[_Iterable[bool]] = ..., is_valid: _Optional[_Iterable[bool]] = ..., active_monitoring_case: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgUSB(_message.Message):
    __slots__ = ("vendor_id", "product_id", "reserved1", "reserved2", "power_consumption", "flags", "vendor_string", "product_string", "serial_number")
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    POWER_CONSUMPTION_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    VENDOR_STRING_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_STRING_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NUMBER_FIELD_NUMBER: _ClassVar[int]
    vendor_id: int
    product_id: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    reserved2: _containers.RepeatedScalarFieldContainer[int]
    power_consumption: int
    flags: int
    vendor_string: _containers.RepeatedScalarFieldContainer[int]
    product_string: _containers.RepeatedScalarFieldContainer[int]
    serial_number: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, vendor_id: _Optional[int] = ..., product_id: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., reserved2: _Optional[_Iterable[int]] = ..., power_consumption: _Optional[int] = ..., flags: _Optional[int] = ..., vendor_string: _Optional[_Iterable[int]] = ..., product_string: _Optional[_Iterable[int]] = ..., serial_number: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_mrr_msgs/msg/active_fault_latched1.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/humble/delphi_mrr_msgs/msg/active_fault_latched1.proto\x12/make87_messages_ros2.humble.delphi_mrr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd7\x12\n\x13\x41\x63tiveFaultLatched1\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit7\x18\x03 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit6\x18\x04 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit5\x18\x05 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte7_bit4\x18\x06 \x01(\x08\x12\x1f\n\x17\x61rm_to_dsp_chksum_fault\x18\x07 \x01(\x08\x12\x1f\n\x17\x64sp_to_arm_chksum_fault\x18\x08 \x01(\x08\x12 \n\x18host_to_arm_chksum_fault\x18\t \x01(\x08\x12 \n\x18\x61rm_to_host_chksum_fault\x18\n \x01(\x08\x12\x1c\n\x14loop_bw_out_of_range\x18\x0b \x01(\x08\x12\x19\n\x11\x64sp_overrun_fault\x18\x0c \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte6_bit5\x18\r \x01(\x08\x12 \n\x18tuning_sensitivity_fault\x18\x0e \x01(\x08\x12#\n\x1bsaturated_tuning_freq_fault\x18\x0f \x01(\x08\x12\x1d\n\x15local_osc_power_fault\x18\x10 \x01(\x08\x12\x1f\n\x17transmitter_power_fault\x18\x11 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte6_bit0\x18\x12 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte5_bit7\x18\x13 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte5_bit6\x18\x14 \x01(\x08\x12\x1d\n\x15xcvr_device_spi_fault\x18\x15 \x01(\x08\x12\"\n\x1a\x66req_synthesizer_spi_fault\x18\x16 \x01(\x08\x12(\n analog_converter_devic_spi_fault\x18\x17 \x01(\x08\x12\x1a\n\x12side_lobe_blockage\x18\x18 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte5_bit1\x18\x19 \x01(\x08\x12\x13\n\x0bmnr_blocked\x18\x1a \x01(\x08\x12\x1b\n\x13\x65\x63u_temp_high_fault\x18\x1b \x01(\x08\x12#\n\x1btransmitter_temp_high_fault\x18\x1c \x01(\x08\x12&\n\x1e\x61lignment_routine_failed_fault\x18\x1d \x01(\x08\x12\x1f\n\x17unreasonable_radar_data\x18\x1e \x01(\x08\x12&\n\x1emicroprocessor_temp_high_fault\x18\x1f \x01(\x08\x12\'\n\x1fvertical_alignment_out_of_range\x18  \x01(\x08\x12)\n!horizontal_alignment_out_of_range\x18! \x01(\x08\x12\x1e\n\x16\x66\x61\x63tory_alignment_mode\x18\" \x01(\x08\x12\x19\n\x11\x62\x61ttery_low_fault\x18# \x01(\x08\x12\x1a\n\x12\x62\x61ttery_high_fault\x18$ \x01(\x08\x12\"\n\x1av_1p25_supply_out_of_range\x18% \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte3_bit4\x18& \x01(\x08\x12\x1f\n\x17thermistor_out_of_range\x18\' \x01(\x08\x12%\n\x1dv_3p3_dac_supply_out_of_range\x18( \x01(\x08\x12%\n\x1dv_3p3_raw_supply_out_of_range\x18) \x01(\x08\x12\x1f\n\x17v_5_supply_out_of_range\x18* \x01(\x08\x12\x1c\n\x14transmitter_id_fault\x18+ \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit6\x18, \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit5\x18- \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit4\x18. \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit3\x18/ \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte2_bit2\x18\x30 \x01(\x08\x12\x1e\n\x16pcan_missing_msg_fault\x18\x31 \x01(\x08\x12\x14\n\x0cpcan_bus_off\x18\x32 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte1_bit7\x18\x33 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte1_bit6\x18\x34 \x01(\x08\x12#\n\x1binstruction_set_check_fault\x18\x35 \x01(\x08\x12\x1c\n\x14stack_overflow_fault\x18\x36 \x01(\x08\x12\x16\n\x0ewatchdog_fault\x18\x37 \x01(\x08\x12\x16\n\x0epll_lock_fault\x18\x38 \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte1_bit1\x18\x39 \x01(\x08\x12\x1d\n\x15ram_memory_test_fault\x18: \x01(\x08\x12\x1c\n\x14usc_validation_fault\x18; \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit6\x18< \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit5\x18= \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit4\x18> \x01(\x08\x12%\n\x1d\x61\x63tive_flt_latched_byte0_bit3\x18? \x01(\x08\x12!\n\x19keep_alive_checksum_fault\x18@ \x01(\x08\x12*\n\"program_calibration_flash_checksum\x18\x41 \x01(\x08\x12(\n application_flash_checksum_fault\x18\x42 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_mrr_msgs.msg.active_fault_latched1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ACTIVEFAULTLATCHED1']._serialized_start=219
  _globals['_ACTIVEFAULTLATCHED1']._serialized_end=2610
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ChangeModeRequest(_message.Message):
    __slots__ = ("mode_name",)
    MODE_NAME_FIELD_NUMBER: _ClassVar[int]
    mode_name: str
    def __init__(self, mode_name: _Optional[str] = ...) -> None: ...

class ChangeModeResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/turtlesim/msg/pose.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages_ros2/jazzy/turtlesim/msg/pose.proto\x12(make87_messages_ros2.jazzy.turtlesim.msg\"^\n\x04Pose\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05theta\x18\x03 \x01(\x02\x12\x17\n\x0flinear_velocity\x18\x04 \x01(\x02\x12\x18\n\x10\x61ngular_velocity\x18\x05 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.turtlesim.msg.pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POSE']._serialized_start=97
  _globals['_POSE']._serialized_end=191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_task_msgs.msg import dispatch_state_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_dispatch__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_states.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\x1a\x41make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_state.proto\"\xac\x01\n\x0e\x44ispatchStates\x12K\n\x06\x61\x63tive\x18\x01 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rmf_task_msgs.msg.DispatchState\x12M\n\x08\x66inished\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rmf_task_msgs.msg.DispatchStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.dispatch_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DISPATCHSTATES']._serialized_start=184
  _globals['_DISPATCHSTATES']._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_motion_plan.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import motion_plan_request_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_motion__plan__request__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import motion_plan_response_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_motion__plan__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/moveit_msgs/srv/get_motion_plan.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/motion_plan_request.proto\x1a\x45make87_messages_ros2/jazzy/moveit_msgs/msg/motion_plan_response.proto\"r\n\x14GetMotionPlanRequest\x12Z\n\x13motion_plan_request\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.moveit_msgs.msg.MotionPlanRequest\"u\n\x15GetMotionPlanResponse\x12\\\n\x14motion_plan_response\x18\x01 \x01(\x0b\x32>.make87_messages_ros2.jazzy.moveit_msgs.msg.MotionPlanResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_motion_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETMOTIONPLANREQUEST']._serialized_start=253
  _globals['_GETMOTIONPLANREQUEST']._serialized_end=367
  _globals['_GETMOTIONPLANRESPONSE']._serialized_start=369
  _globals['_GETMOTIONPLANRESPONSE']._serialized_end=486
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import joint_limits_pb2 as _joint_limits_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class KinematicSolverInfo(_message.Message):
    __slots__ = ("header", "joint_names", "limits", "link_names")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_NAMES_FIELD_NUMBER: _ClassVar[int]
    LIMITS_FIELD_NUMBER: _ClassVar[int]
    LINK_NAMES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    joint_names: _containers.RepeatedScalarFieldContainer[str]
    limits: _containers.RepeatedCompositeFieldContainer[_joint_limits_pb2.JointLimits]
    link_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., joint_names: _Optional[_Iterable[str]] = ..., limits: _Optional[_Iterable[_Union[_joint_limits_pb2.JointLimits, _Mapping]]] = ..., link_names: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/srv/set_io.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages_ros2/jazzy/ur_msgs/srv/set_io.proto\x12&make87_messages_ros2.jazzy.ur_msgs.srv\"7\n\x0cSetIORequest\x12\x0b\n\x03\x66un\x18\x01 \x01(\x05\x12\x0b\n\x03pin\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x02\" \n\rSetIOResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.srv.set_io_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETIOREQUEST']._serialized_start=95
  _globals['_SETIOREQUEST']._serialized_end=150
  _globals['_SETIORESPONSE']._serialized_start=152
  _globals['_SETIORESPONSE']._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_physics_properties.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.gazebo_msgs.msg import ode_physics_pb2 as make87__messages__ros2_dot_jazzy_dot_gazebo__msgs_dot_msg_dot_ode__physics__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_physics_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a<make87_messages_ros2/jazzy/gazebo_msgs/msg/ode_physics.proto\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\"\x1d\n\x1bGetPhysicsPropertiesRequest\"\x96\x02\n\x1cGetPhysicsPropertiesResponse\x12\x11\n\ttime_step\x18\x01 \x01(\x01\x12\r\n\x05pause\x18\x02 \x01(\x08\x12\x17\n\x0fmax_update_rate\x18\x03 \x01(\x01\x12\x46\n\x07gravity\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12J\n\node_config\x18\x05 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.gazebo_msgs.msg.ODEPhysics\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\x16\n\x0estatus_message\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_physics_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPHYSICSPROPERTIESREQUEST']._serialized_start=241
  _globals['_GETPHYSICSPROPERTIESREQUEST']._serialized_end=270
  _globals['_GETPHYSICSPROPERTIESRESPONSE']._serialized_start=273
  _globals['_GETPHYSICSPROPERTIESRESPONSE']._serialized_end=551
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import planner_params_pb2 as _planner_params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPlannerParamsRequest(_message.Message):
    __slots__ = ("header", "pipeline_id", "planner_config", "group")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PIPELINE_ID_FIELD_NUMBER: _ClassVar[int]
    PLANNER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pipeline_id: str
    planner_config: str
    group: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pipeline_id: _Optional[str] = ..., planner_config: _Optional[str] = ..., group: _Optional[str] = ...) -> None: ...

class GetPlannerParamsResponse(_message.Message):
    __slots__ = ("header", "params")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    params: _planner_params_pb2.PlannerParams
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., params: _Optional[_Union[_planner_params_pb2.PlannerParams, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrStatus3(_message.Message):
    __slots__ = ("header", "can_tx_alignment_state", "can_tx_interface_ver_minor", "can_tx_sw_version_arm", "can_tx_hw_version", "can_tx_interface_version", "can_tx_serial_num")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_ALIGNMENT_STATE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_INTERFACE_VER_MINOR_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_SW_VERSION_ARM_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_HW_VERSION_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_INTERFACE_VERSION_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_SERIAL_NUM_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_tx_alignment_state: int
    can_tx_interface_ver_minor: int
    can_tx_sw_version_arm: int
    can_tx_hw_version: int
    can_tx_interface_version: int
    can_tx_serial_num: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_tx_alignment_state: _Optional[int] = ..., can_tx_interface_ver_minor: _Optional[int] = ..., can_tx_sw_version_arm: _Optional[int] = ..., can_tx_hw_version: _Optional[int] = ..., can_tx_interface_version: _Optional[int] = ..., can_tx_serial_num: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.rtabmap_msgs.msg import map_data_pb2 as _map_data_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMapRequest(_message.Message):
    __slots__ = ("global_map", "optimized", "graph_only")
    GLOBAL_MAP_FIELD_NUMBER: _ClassVar[int]
    OPTIMIZED_FIELD_NUMBER: _ClassVar[int]
    GRAPH_ONLY_FIELD_NUMBER: _ClassVar[int]
    global_map: bool
    optimized: bool
    graph_only: bool
    def __init__(self, global_map: bool = ..., optimized: bool = ..., graph_only: bool = ...) -> None: ...

class GetMapResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _map_data_pb2.MapData
    def __init__(self, data: _Optional[_Union[_map_data_pb2.MapData, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Match(_message.Message):
    __slots__ = ("header", "template_id", "uuid", "pose", "grasp_uuids", "score")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    GRASP_UUIDS_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    template_id: str
    uuid: str
    pose: _pose_stamped_pb2.PoseStamped
    grasp_uuids: _containers.RepeatedScalarFieldContainer[str]
    score: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., template_id: _Optional[str] = ..., uuid: _Optional[str] = ..., pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., grasp_uuids: _Optional[_Iterable[str]] = ..., score: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/grasping_msgs/msg/graspable_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.grasping_msgs.msg import object_pb2 as make87__messages__ros2_dot_rolling_dot_grasping__msgs_dot_msg_dot_object__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_grasp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/grasping_msgs/msg/graspable_object.proto\x12.make87_messages_ros2.rolling.grasping_msgs.msg\x1a;make87_messages_ros2/rolling/grasping_msgs/msg/object.proto\x1a\x38make87_messages_ros2/rolling/moveit_msgs/msg/grasp.proto\"\x9e\x01\n\x0fGraspableObject\x12\x46\n\x06object\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.grasping_msgs.msg.Object\x12\x43\n\x06grasps\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.moveit_msgs.msg.Graspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.grasping_msgs.msg.graspable_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRASPABLEOBJECT']._serialized_start=241
  _globals['_GRASPABLEOBJECT']._serialized_end=399
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgDAT(_message.Message):
    __slots__ = ("datum_num", "datum_name", "maj_a", "flat", "d_x", "d_y", "d_z", "rot_x", "rot_y", "rot_z", "scale")
    DATUM_NUM_FIELD_NUMBER: _ClassVar[int]
    DATUM_NAME_FIELD_NUMBER: _ClassVar[int]
    MAJ_A_FIELD_NUMBER: _ClassVar[int]
    FLAT_FIELD_NUMBER: _ClassVar[int]
    D_X_FIELD_NUMBER: _ClassVar[int]
    D_Y_FIELD_NUMBER: _ClassVar[int]
    D_Z_FIELD_NUMBER: _ClassVar[int]
    ROT_X_FIELD_NUMBER: _ClassVar[int]
    ROT_Y_FIELD_NUMBER: _ClassVar[int]
    ROT_Z_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    datum_num: int
    datum_name: _containers.RepeatedScalarFieldContainer[int]
    maj_a: float
    flat: float
    d_x: float
    d_y: float
    d_z: float
    rot_x: float
    rot_y: float
    rot_z: float
    scale: float
    def __init__(self, datum_num: _Optional[int] = ..., datum_name: _Optional[_Iterable[int]] = ..., maj_a: _Optional[float] = ..., flat: _Optional[float] = ..., d_x: _Optional[float] = ..., d_y: _Optional[float] = ..., d_z: _Optional[float] = ..., rot_x: _Optional[float] = ..., rot_y: _Optional[float] = ..., rot_z: _Optional[float] = ..., scale: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nav2_msgs/srv/load_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_jazzy_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/nav2_msgs/srv/load_map.proto\x12(make87_messages_ros2.jazzy.nav2_msgs.srv\x1a<make87_messages_ros2/jazzy/nav_msgs/msg/occupancy_grid.proto\"!\n\x0eLoadMapRequest\x12\x0f\n\x07map_url\x18\x01 \x01(\t\"f\n\x0fLoadMapResponse\x12\x43\n\x03map\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.nav_msgs.msg.OccupancyGrid\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nav2_msgs.srv.load_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOADMAPREQUEST']._serialized_start=163
  _globals['_LOADMAPREQUEST']._serialized_end=196
  _globals['_LOADMAPRESPONSE']._serialized_start=198
  _globals['_LOADMAPRESPONSE']._serialized_end=300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/neobotix_usboard_msgs/msg/sensor_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/neobotix_usboard_msgs/msg/sensor_data.proto\x12\x36make87_messages_ros2.rolling.neobotix_usboard_msgs.msg\"K\n\nSensorData\x12\x10\n\x08\x64istance\x18\x01 \x01(\r\x12\x0c\n\x04warn\x18\x02 \x01(\x08\x12\r\n\x05\x61larm\x18\x03 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.neobotix_usboard_msgs.msg.sensor_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENSORDATA']._serialized_start=132
  _globals['_SENSORDATA']._serialized_end=207
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.ur_dashboard_msgs.msg import program_state_pb2 as _program_state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetProgramStateRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetProgramStateResponse(_message.Message):
    __slots__ = ("state", "program_name", "answer", "success")
    STATE_FIELD_NUMBER: _ClassVar[int]
    PROGRAM_NAME_FIELD_NUMBER: _ClassVar[int]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    state: _program_state_pb2.ProgramState
    program_name: str
    answer: str
    success: bool
    def __init__(self, state: _Optional[_Union[_program_state_pb2.ProgramState, _Mapping]] = ..., program_name: _Optional[str] = ..., answer: _Optional[str] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Frame16(_message.Message):
    __slots__ = ("header", "id", "extended", "fdf", "brs", "esi", "rtr", "size", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTENDED_FIELD_NUMBER: _ClassVar[int]
    FDF_FIELD_NUMBER: _ClassVar[int]
    BRS_FIELD_NUMBER: _ClassVar[int]
    ESI_FIELD_NUMBER: _ClassVar[int]
    RTR_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    extended: bool
    fdf: bool
    brs: bool
    esi: bool
    rtr: bool
    size: int
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., extended: bool = ..., fdf: bool = ..., brs: bool = ..., esi: bool = ..., rtr: bool = ..., size: _Optional[int] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/roi_observation_safety_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n`make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/roi_observation_safety_data.proto\x12>make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg\"\x8a\x03\n\x18ROIObservationSafetyData\x12%\n\x1dinvalid_due_to_invalid_pixels\x18\x01 \x01(\r\x12\x1f\n\x17invalid_due_to_variance\x18\x02 \x01(\r\x12#\n\x1binvalid_due_to_overexposure\x18\x03 \x01(\r\x12$\n\x1cinvalid_due_to_underexposure\x18\x04 \x01(\r\x12(\n invalid_due_to_temporal_variance\x18\x05 \x01(\r\x12\x33\n+invalid_due_to_outside_of_measurement_range\x18\x06 \x01(\r\x12\x33\n+invalid_due_to_retro_reflector_interference\x18\x07 \x01(\r\x12\x1b\n\x13\x63ontamination_error\x18\x08 \x01(\r\x12\x15\n\rquality_class\x18\t \x01(\r\x12\x13\n\x0bslot_active\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.roi_observation_safety_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROIOBSERVATIONSAFETYDATA']._serialized_start=165
  _globals['_ROIOBSERVATIONSAFETYDATA']._serialized_end=559
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AddProblemRequest(_message.Message):
    __slots__ = ("problem",)
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    problem: str
    def __init__(self, problem: _Optional[str] = ...) -> None: ...

class AddProblemResponse(_message.Message):
    __slots__ = ("success", "error_info")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_info: str
    def __init__(self, success: bool = ..., error_info: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.situational_graphs_msgs.msg import plane_data_pb2 as _plane_data_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.visualization_msgs.msg import marker_array_pb2 as _marker_array_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RoomData(_message.Message):
    __slots__ = ("header", "ros2_header", "id", "neighbour_ids", "room_length", "room_center", "cluster_center", "x_planes", "y_planes", "planes", "cluster_array")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NEIGHBOUR_IDS_FIELD_NUMBER: _ClassVar[int]
    ROOM_LENGTH_FIELD_NUMBER: _ClassVar[int]
    ROOM_CENTER_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_CENTER_FIELD_NUMBER: _ClassVar[int]
    X_PLANES_FIELD_NUMBER: _ClassVar[int]
    Y_PLANES_FIELD_NUMBER: _ClassVar[int]
    PLANES_FIELD_NUMBER: _ClassVar[int]
    CLUSTER_ARRAY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    id: int
    neighbour_ids: _containers.RepeatedScalarFieldContainer[int]
    room_length: _point_pb2.Point
    room_center: _pose_pb2.Pose
    cluster_center: _point_pb2.Point
    x_planes: _containers.RepeatedCompositeFieldContainer[_plane_data_pb2.PlaneData]
    y_planes: _containers.RepeatedCompositeFieldContainer[_plane_data_pb2.PlaneData]
    planes: _containers.RepeatedCompositeFieldContainer[_plane_data_pb2.PlaneData]
    cluster_array: _marker_array_pb2.MarkerArray
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., id: _Optional[int] = ..., neighbour_ids: _Optional[_Iterable[int]] = ..., room_length: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., room_center: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., cluster_center: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., x_planes: _Optional[_Iterable[_Union[_plane_data_pb2.PlaneData, _Mapping]]] = ..., y_planes: _Optional[_Iterable[_Union[_plane_data_pb2.PlaneData, _Mapping]]] = ..., planes: _Optional[_Iterable[_Union[_plane_data_pb2.PlaneData, _Mapping]]] = ..., cluster_array: _Optional[_Union[_marker_array_pb2.MarkerArray, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ChargingAssignment(_message.Message):
    __slots__ = ("robot_name", "waypoint_name", "mode")
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    WAYPOINT_NAME_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    robot_name: str
    waypoint_name: str
    mode: int
    def __init__(self, robot_name: _Optional[str] = ..., waypoint_name: _Optional[str] = ..., mode: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/srv/get_domain_actions.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import empty_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/plansys2_msgs/srv/get_domain_actions.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.srv\x1a\x33make87_messages_ros2/jazzy/std_msgs/msg/empty.proto\"Z\n\x17GetDomainActionsRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32..make87_messages_ros2.jazzy.std_msgs.msg.Empty\"P\n\x18GetDomainActionsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x61\x63tions\x18\x02 \x03(\t\x12\x12\n\nerror_info\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.srv.get_domain_actions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETDOMAINACTIONSREQUEST']._serialized_start=172
  _globals['_GETDOMAINACTIONSREQUEST']._serialized_end=262
  _globals['_GETDOMAINACTIONSRESPONSE']._serialized_start=264
  _globals['_GETDOMAINACTIONSRESPONSE']._serialized_end=344
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/nav_sbas.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import nav_sbassv_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_nav__sbassv__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/nav_sbas.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a:make87_messages_ros2/jazzy/ublox_msgs/msg/nav_sbassv.proto\"\xb3\x01\n\x07NavSBAS\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\x0b\n\x03geo\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x0b\n\x03sys\x18\x04 \x01(\x05\x12\x0f\n\x07service\x18\x05 \x01(\r\x12\x0b\n\x03\x63nt\x18\x06 \x01(\r\x12\x11\n\treserved0\x18\x07 \x03(\r\x12@\n\x02sv\x18\x08 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.ublox_msgs.msg.NavSBASSVb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.nav_sbas_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVSBAS']._serialized_start=164
  _globals['_NAVSBAS']._serialized_end=343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/game_controller_spl_interfaces/msg/team_info15.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.game_controller_spl_interfaces.msg import robot_info15_pb2 as make87__messages__ros2_dot_humble_dot_game__controller__spl__interfaces_dot_msg_dot_robot__info15__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/game_controller_spl_interfaces/msg/team_info15.proto\x12>make87_messages_ros2.humble.game_controller_spl_interfaces.msg\x1a!make87_messages/core/header.proto\x1aQmake87_messages_ros2/humble/game_controller_spl_interfaces/msg/robot_info15.proto\"\xe1\x02\n\nTeamInfo15\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0bteam_number\x18\x02 \x01(\r\x12\x1b\n\x13\x66ield_player_colour\x18\x03 \x01(\r\x12\x19\n\x11goalkeeper_colour\x18\x04 \x01(\r\x12\x12\n\ngoalkeeper\x18\x05 \x01(\r\x12\x13\n\x0bteam_colour\x18\x06 \x01(\r\x12\r\n\x05score\x18\x07 \x01(\r\x12\x14\n\x0cpenalty_shot\x18\x08 \x01(\r\x12\x14\n\x0csingle_shots\x18\t \x01(\r\x12\x16\n\x0emessage_budget\x18\n \x01(\r\x12\\\n\x07players\x18\x0b \x03(\x0b\x32K.make87_messages_ros2.humble.game_controller_spl_interfaces.msg.RobotInfo15b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.game_controller_spl_interfaces.msg.team_info15_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TEAMINFO15']._serialized_start=267
  _globals['_TEAMINFO15']._serialized_end=620
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/septentrio_gnss_driver/msg/vector_info_geod.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/septentrio_gnss_driver/msg/vector_info_geod.proto\x12\x37make87_messages_ros2.rolling.septentrio_gnss_driver.msg\"\x9c\x02\n\x0eVectorInfoGeod\x12\r\n\x05nr_sv\x18\x01 \x01(\r\x12\r\n\x05\x65rror\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x0c\n\x04misc\x18\x04 \x01(\r\x12\x12\n\ndelta_east\x18\x05 \x01(\x01\x12\x13\n\x0b\x64\x65lta_north\x18\x06 \x01(\x01\x12\x10\n\x08\x64\x65lta_up\x18\x07 \x01(\x01\x12\x10\n\x08\x64\x65lta_ve\x18\x08 \x01(\x02\x12\x10\n\x08\x64\x65lta_vn\x18\t \x01(\x02\x12\x10\n\x08\x64\x65lta_vu\x18\n \x01(\x02\x12\x0f\n\x07\x61zimuth\x18\x0b \x01(\r\x12\x11\n\televation\x18\x0c \x01(\x05\x12\x14\n\x0creference_id\x18\r \x01(\r\x12\x10\n\x08\x63orr_age\x18\x0e \x01(\r\x12\x13\n\x0bsignal_info\x18\x0f \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.septentrio_gnss_driver.msg.vector_info_geod_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VECTORINFOGEOD']._serialized_start=140
  _globals['_VECTORINFOGEOD']._serialized_end=424
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ros2cli_test_interfaces.msg import short_varied_nested_pb2 as make87__messages__ros2_dot_jazzy_dot_ros2cli__test__interfaces_dot_msg_dot_short__varied__nested__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVmake87_messages_ros2/jazzy/ros2cli_test_interfaces/srv/short_varied_multi_nested.proto\x12\x36make87_messages_ros2.jazzy.ros2cli_test_interfaces.srv\x1aPmake87_messages_ros2/jazzy/ros2cli_test_interfaces/msg/short_varied_nested.proto\"\x87\x01\n\x1dShortVariedMultiNestedRequest\x12\x66\n\x13short_varied_nested\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.jazzy.ros2cli_test_interfaces.msg.ShortVariedNested\"4\n\x1eShortVariedMultiNestedResponse\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros2cli_test_interfaces.srv.short_varied_multi_nested_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_start=229
  _globals['_SHORTVARIEDMULTINESTEDREQUEST']._serialized_end=364
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_start=366
  _globals['_SHORTVARIEDMULTINESTEDRESPONSE']._serialized_end=418
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrientationConstraint(_message.Message):
    __slots__ = ("header", "ros2_header", "orientation", "link_name", "absolute_x_axis_tolerance", "absolute_y_axis_tolerance", "absolute_z_axis_tolerance", "parameterization", "weight")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_X_AXIS_TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_Y_AXIS_TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_Z_AXIS_TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    PARAMETERIZATION_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    orientation: _quaternion_pb2.Quaternion
    link_name: str
    absolute_x_axis_tolerance: float
    absolute_y_axis_tolerance: float
    absolute_z_axis_tolerance: float
    parameterization: int
    weight: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., orientation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., link_name: _Optional[str] = ..., absolute_x_axis_tolerance: _Optional[float] = ..., absolute_y_axis_tolerance: _Optional[float] = ..., absolute_z_axis_tolerance: _Optional[float] = ..., parameterization: _Optional[int] = ..., weight: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ("header", "device_number", "device_name", "bus_voltage", "temperature", "output_voltage", "analog_input", "mode", "fault")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DEVICE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    BUS_VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    FAULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    device_number: int
    device_name: str
    bus_voltage: float
    temperature: float
    output_voltage: float
    analog_input: float
    mode: int
    fault: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., device_number: _Optional[int] = ..., device_name: _Optional[str] = ..., bus_voltage: _Optional[float] = ..., temperature: _Optional[float] = ..., output_voltage: _Optional[float] = ..., analog_input: _Optional[float] = ..., mode: _Optional[int] = ..., fault: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetPenRequest(_message.Message):
    __slots__ = ("r", "g", "b", "width", "off")
    R_FIELD_NUMBER: _ClassVar[int]
    G_FIELD_NUMBER: _ClassVar[int]
    B_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    OFF_FIELD_NUMBER: _ClassVar[int]
    r: int
    g: int
    b: int
    width: int
    off: int
    def __init__(self, r: _Optional[int] = ..., g: _Optional[int] = ..., b: _Optional[int] = ..., width: _Optional[int] = ..., off: _Optional[int] = ...) -> None: ...

class SetPenResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SteeringDiagnostics(_message.Message):
    __slots__ = ("header", "ros2_header", "degraded", "degraded_cmd_type", "degraded_comms", "degraded_comms_dbw", "degraded_comms_dbw_gateway", "degraded_comms_dbw_brake", "degraded_comms_dbw_thrtl", "degraded_comms_dbw_gear", "degraded_comms_vehicle", "degraded_comms_actuator", "degraded_internal", "degraded_control_performance", "degraded_param_mismatch", "degraded_vehicle", "degraded_actuator", "degraded_vehicle_speed", "degraded_calibration", "fault", "fault_power", "fault_comms", "fault_comms_dbw", "fault_comms_dbw_gateway", "fault_comms_dbw_brake", "fault_comms_dbw_thrtl", "fault_comms_dbw_gear", "fault_comms_vehicle", "fault_comms_actuator", "fault_internal", "fault_vehicle", "fault_vehicle_speed", "fault_angle_sensor", "fault_torque_sensor_1", "fault_torque_sensor_2", "fault_torque_sensor_mismatch", "fault_actuator", "fault_actuator_torque_sensor", "fault_actuator_config", "fault_actuator_assist", "fault_control_performance", "fault_param_mismatch", "fault_param_limits", "fault_calibration")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_CMD_TYPE_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_DBW_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_DBW_GATEWAY_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_DBW_BRAKE_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_DBW_THRTL_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_DBW_GEAR_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_VEHICLE_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_COMMS_ACTUATOR_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_INTERNAL_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_CONTROL_PERFORMANCE_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_PARAM_MISMATCH_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_VEHICLE_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_ACTUATOR_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_VEHICLE_SPEED_FIELD_NUMBER: _ClassVar[int]
    DEGRADED_CALIBRATION_FIELD_NUMBER: _ClassVar[int]
    FAULT_FIELD_NUMBER: _ClassVar[int]
    FAULT_POWER_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_DBW_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_DBW_GATEWAY_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_DBW_BRAKE_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_DBW_THRTL_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_DBW_GEAR_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_VEHICLE_FIELD_NUMBER: _ClassVar[int]
    FAULT_COMMS_ACTUATOR_FIELD_NUMBER: _ClassVar[int]
    FAULT_INTERNAL_FIELD_NUMBER: _ClassVar[int]
    FAULT_VEHICLE_FIELD_NUMBER: _ClassVar[int]
    FAULT_VEHICLE_SPEED_FIELD_NUMBER: _ClassVar[int]
    FAULT_ANGLE_SENSOR_FIELD_NUMBER: _ClassVar[int]
    FAULT_TORQUE_SENSOR_1_FIELD_NUMBER: _ClassVar[int]
    FAULT_TORQUE_SENSOR_2_FIELD_NUMBER: _ClassVar[int]
    FAULT_TORQUE_SENSOR_MISMATCH_FIELD_NUMBER: _ClassVar[int]
    FAULT_ACTUATOR_FIELD_NUMBER: _ClassVar[int]
    FAULT_ACTUATOR_TORQUE_SENSOR_FIELD_NUMBER: _ClassVar[int]
    FAULT_ACTUATOR_CONFIG_FIELD_NUMBER: _ClassVar[int]
    FAULT_ACTUATOR_ASSIST_FIELD_NUMBER: _ClassVar[int]
    FAULT_CONTROL_PERFORMANCE_FIELD_NUMBER: _ClassVar[int]
    FAULT_PARAM_MISMATCH_FIELD_NUMBER: _ClassVar[int]
    FAULT_PARAM_LIMITS_FIELD_NUMBER: _ClassVar[int]
    FAULT_CALIBRATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    degraded: bool
    degraded_cmd_type: bool
    degraded_comms: bool
    degraded_comms_dbw: bool
    degraded_comms_dbw_gateway: bool
    degraded_comms_dbw_brake: bool
    degraded_comms_dbw_thrtl: bool
    degraded_comms_dbw_gear: bool
    degraded_comms_vehicle: bool
    degraded_comms_actuator: bool
    degraded_internal: bool
    degraded_control_performance: bool
    degraded_param_mismatch: bool
    degraded_vehicle: bool
    degraded_actuator: bool
    degraded_vehicle_speed: bool
    degraded_calibration: bool
    fault: bool
    fault_power: bool
    fault_comms: bool
    fault_comms_dbw: bool
    fault_comms_dbw_gateway: bool
    fault_comms_dbw_brake: bool
    fault_comms_dbw_thrtl: bool
    fault_comms_dbw_gear: bool
    fault_comms_vehicle: bool
    fault_comms_actuator: bool
    fault_internal: bool
    fault_vehicle: bool
    fault_vehicle_speed: bool
    fault_angle_sensor: bool
    fault_torque_sensor_1: bool
    fault_torque_sensor_2: bool
    fault_torque_sensor_mismatch: bool
    fault_actuator: bool
    fault_actuator_torque_sensor: bool
    fault_actuator_config: bool
    fault_actuator_assist: bool
    fault_control_performance: bool
    fault_param_mismatch: bool
    fault_param_limits: bool
    fault_calibration: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., degraded: bool = ..., degraded_cmd_type: bool = ..., degraded_comms: bool = ..., degraded_comms_dbw: bool = ..., degraded_comms_dbw_gateway: bool = ..., degraded_comms_dbw_brake: bool = ..., degraded_comms_dbw_thrtl: bool = ..., degraded_comms_dbw_gear: bool = ..., degraded_comms_vehicle: bool = ..., degraded_comms_actuator: bool = ..., degraded_internal: bool = ..., degraded_control_performance: bool = ..., degraded_param_mismatch: bool = ..., degraded_vehicle: bool = ..., degraded_actuator: bool = ..., degraded_vehicle_speed: bool = ..., degraded_calibration: bool = ..., fault: bool = ..., fault_power: bool = ..., fault_comms: bool = ..., fault_comms_dbw: bool = ..., fault_comms_dbw_gateway: bool = ..., fault_comms_dbw_brake: bool = ..., fault_comms_dbw_thrtl: bool = ..., fault_comms_dbw_gear: bool = ..., fault_comms_vehicle: bool = ..., fault_comms_actuator: bool = ..., fault_internal: bool = ..., fault_vehicle: bool = ..., fault_vehicle_speed: bool = ..., fault_angle_sensor: bool = ..., fault_torque_sensor_1: bool = ..., fault_torque_sensor_2: bool = ..., fault_torque_sensor_mismatch: bool = ..., fault_actuator: bool = ..., fault_actuator_torque_sensor: bool = ..., fault_actuator_config: bool = ..., fault_actuator_assist: bool = ..., fault_control_performance: bool = ..., fault_param_mismatch: bool = ..., fault_param_limits: bool = ..., fault_calibration: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros_ign_interfaces/srv/spawn_entity.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import entity_factory_pb2 as make87__messages__ros2_dot_humble_dot_ros__gz__interfaces_dot_msg_dot_entity__factory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/ros_ign_interfaces/srv/spawn_entity.proto\x12\x32make87_messages_ros2.humble.ros_ign_interfaces.srv\x1a!make87_messages/core/header.proto\x1a\x46make87_messages_ros2/humble/ros_gz_interfaces/msg/entity_factory.proto\"\x9c\x01\n\x12SpawnEntityRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12X\n\x0e\x65ntity_factory\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.ros_gz_interfaces.msg.EntityFactory\"T\n\x13SpawnEntityResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros_ign_interfaces.srv.spawn_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SPAWNENTITYREQUEST']._serialized_start=233
  _globals['_SPAWNENTITYREQUEST']._serialized_end=389
  _globals['_SPAWNENTITYRESPONSE']._serialized_start=391
  _globals['_SPAWNENTITYRESPONSE']._serialized_end=475
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import schedule_identity_pb2 as _schedule_identity_pb2
from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import schedule_query_pb2 as _schedule_query_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RegisterQueryRequest(_message.Message):
    __slots__ = ("query",)
    QUERY_FIELD_NUMBER: _ClassVar[int]
    query: _schedule_query_pb2.ScheduleQuery
    def __init__(self, query: _Optional[_Union[_schedule_query_pb2.ScheduleQuery, _Mapping]] = ...) -> None: ...

class RegisterQueryResponse(_message.Message):
    __slots__ = ("node_id", "query_id", "error")
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    node_id: _schedule_identity_pb2.ScheduleIdentity
    query_id: int
    error: str
    def __init__(self, node_id: _Optional[_Union[_schedule_identity_pb2.ScheduleIdentity, _Mapping]] = ..., query_id: _Optional[int] = ..., error: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_scheduler_msgs.msg import schedule_pb2 as _schedule_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListSchedulesRequest(_message.Message):
    __slots__ = ("created_after",)
    CREATED_AFTER_FIELD_NUMBER: _ClassVar[int]
    created_after: int
    def __init__(self, created_after: _Optional[int] = ...) -> None: ...

class ListSchedulesResponse(_message.Message):
    __slots__ = ("success", "message", "schedules")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SCHEDULES_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    schedules: _containers.RepeatedCompositeFieldContainer[_schedule_pb2.Schedule]
    def __init__(self, success: bool = ..., message: _Optional[str] = ..., schedules: _Optional[_Iterable[_Union[_schedule_pb2.Schedule, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrStatus2(_message.Message):
    __slots__ = ("header", "can_tx_alignment_status", "can_tx_comm_error", "can_tx_steering_angle_sign", "can_tx_yaw_rate_bias", "can_tx_veh_spd_comp_factor", "can_tx_sw_version_dsp", "can_tx_temperature", "can_tx_range_perf_error", "can_tx_overheat_error", "can_tx_internal_error", "can_tx_xcvr_operational", "can_tx_steering_angle", "can_tx_rolling_count_2")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_ALIGNMENT_STATUS_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_COMM_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_STEERING_ANGLE_SIGN_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_YAW_RATE_BIAS_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_VEH_SPD_COMP_FACTOR_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_SW_VERSION_DSP_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_RANGE_PERF_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_OVERHEAT_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_INTERNAL_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_XCVR_OPERATIONAL_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_STEERING_ANGLE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_ROLLING_COUNT_2_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_tx_alignment_status: int
    can_tx_comm_error: bool
    can_tx_steering_angle_sign: bool
    can_tx_yaw_rate_bias: float
    can_tx_veh_spd_comp_factor: float
    can_tx_sw_version_dsp: int
    can_tx_temperature: int
    can_tx_range_perf_error: bool
    can_tx_overheat_error: bool
    can_tx_internal_error: bool
    can_tx_xcvr_operational: bool
    can_tx_steering_angle: int
    can_tx_rolling_count_2: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_tx_alignment_status: _Optional[int] = ..., can_tx_comm_error: bool = ..., can_tx_steering_angle_sign: bool = ..., can_tx_yaw_rate_bias: _Optional[float] = ..., can_tx_veh_spd_comp_factor: _Optional[float] = ..., can_tx_sw_version_dsp: _Optional[int] = ..., can_tx_temperature: _Optional[int] = ..., can_tx_range_perf_error: bool = ..., can_tx_overheat_error: bool = ..., can_tx_internal_error: bool = ..., can_tx_xcvr_operational: bool = ..., can_tx_steering_angle: _Optional[int] = ..., can_tx_rolling_count_2: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rc_reason_msgs/msg/load_carrier_model.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import box_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_box__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/rc_reason_msgs/msg/load_carrier_model.proto\x12.make87_messages_ros2.humble.rc_reason_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a\x38make87_messages_ros2/humble/rc_reason_msgs/msg/box.proto\x1a>make87_messages_ros2/humble/rc_reason_msgs/msg/rectangle.proto\"\xa8\x04\n\x10LoadCarrierModel\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12M\n\x10outer_dimensions\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.humble.rc_reason_msgs.msg.Box\x12M\n\x10inner_dimensions\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.humble.rc_reason_msgs.msg.Box\x12P\n\rrim_thickness\x18\x06 \x01(\x0b\x32\x39.make87_messages_ros2.humble.rc_reason_msgs.msg.Rectangle\x12\x17\n\x0frim_step_height\x18\x07 \x01(\x01\x12L\n\trim_ledge\x18\x08 \x01(\x0b\x32\x39.make87_messages_ros2.humble.rc_reason_msgs.msg.Rectangle\x12\x18\n\x10height_open_side\x18\t \x01(\x01\x12H\n\x04pose\x18\n \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12\x11\n\tpose_type\x18\x0b \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rc_reason_msgs.msg.load_carrier_model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOADCARRIERMODEL']._serialized_start=347
  _globals['_LOADCARRIERMODEL']._serialized_end=899
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.gazebo_msgs.msg import entity_state_pb2 as _entity_state_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetEntityStateRequest(_message.Message):
    __slots__ = ("name", "reference_frame")
    NAME_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FRAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    reference_frame: str
    def __init__(self, name: _Optional[str] = ..., reference_frame: _Optional[str] = ...) -> None: ...

class GetEntityStateResponse(_message.Message):
    __slots__ = ("header", "state", "success")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    state: _entity_state_pb2.EntityState
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., state: _Optional[_Union[_entity_state_pb2.EntityState, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LIDoutputstateMsg(_message.Message):
    __slots__ = ("header", "ros2_header", "version_number", "system_counter", "output_state", "output_count", "time_state", "year", "month", "day", "hour", "minute", "second", "microsecond")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_COUNTER_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_STATE_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_COUNT_FIELD_NUMBER: _ClassVar[int]
    TIME_STATE_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MINUTE_FIELD_NUMBER: _ClassVar[int]
    SECOND_FIELD_NUMBER: _ClassVar[int]
    MICROSECOND_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    version_number: int
    system_counter: int
    output_state: _containers.RepeatedScalarFieldContainer[int]
    output_count: _containers.RepeatedScalarFieldContainer[int]
    time_state: int
    year: int
    month: int
    day: int
    hour: int
    minute: int
    second: int
    microsecond: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., version_number: _Optional[int] = ..., system_counter: _Optional[int] = ..., output_state: _Optional[_Iterable[int]] = ..., output_count: _Optional[_Iterable[int]] = ..., time_state: _Optional[int] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., minute: _Optional[int] = ..., second: _Optional[int] = ..., microsecond: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_scheduler_msgs/srv/cancel_schedule.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_scheduler_msgs/srv/cancel_schedule.proto\x12\x33make87_messages_ros2.rolling.rmf_scheduler_msgs.srv\"7\n\x15\x43\x61ncelScheduleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x66inished\x18\x02 \x01(\x08\":\n\x16\x43\x61ncelScheduleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_scheduler_msgs.srv.cancel_schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CANCELSCHEDULEREQUEST']._serialized_start=130
  _globals['_CANCELSCHEDULEREQUEST']._serialized_end=185
  _globals['_CANCELSCHEDULERESPONSE']._serialized_start=187
  _globals['_CANCELSCHEDULERESPONSE']._serialized_end=245
# @@protoc_insertion_point(module_scope)
